#include <iostream>
#include "dlgsharelist.h"
#include "globals.h"
#include <qlabel.h>

using namespace std;

DlgShareList::DlgShareList(QWidget *parent, const char *name)
		: QWidget(parent, name) {
	layoutMain = new QVBoxLayout(this, 0, -1, "vertical layout");
	shareList = new QListView(this, "share list box");
	layoutBtns = new QHBox(this, "horizontal layout");
	motdBox = new QTextEdit(this, "message of the day text box");
	btnOK = new QPushButton("Choose", layoutBtns, "choose button");
	btnCancel = new QPushButton("Cancel", layoutBtns, "cancel button");
	QLabel *motdLabel = new QLabel("  Message of the day", this, "motd label");

	this->resize(500,300);
	this->setCaption("Choose a remote share");

	layoutMain->addWidget(shareList);
	layoutMain->addWidget(motdLabel);
	layoutMain->addWidget(motdBox);
	layoutMain->addWidget(layoutBtns);
	shareList->addColumn("Share Name");
	shareList->addColumn("Description");
	
	motdBox->setReadOnly(true);
	btnOK->setMaximumWidth(100);
	btnCancel->setMaximumWidth(100);

	connect(shareList, SIGNAL(selectionChanged()), this, SLOT(updateStatus()));
	connect(shareList, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(listDoubleClicked(QListViewItem *)));
	connect(btnOK, SIGNAL(clicked()), this, SLOT(tryFinish()));
	connect(btnCancel, SIGNAL(clicked()), this, SLOT(cancel()));

	updateStatus();
}

void DlgShareList::addShare(QString name, QString description) {
	new QListViewItem(shareList, name, description);
}

void DlgShareList::clearList() {
	shareList->clear();
}

void DlgShareList::setMotd(QStringList motd) {
	motdBox->clear();
	for (QStringList::iterator it = motd.begin(); it != motd.end(); it++)
		motdBox->append(*it);
}

void DlgShareList::updateStatus() {
	if (!shareList->selectedItem())
		btnOK->setEnabled(false);
	else {
		btnOK->setEnabled(true);
	}
}

void DlgShareList::listDoubleClicked(QListViewItem *item) {
	if (item) tryFinish();
}

void DlgShareList::tryFinish() {
	emit shareChosen((*shareList->selectedItem()).text(0));
	this->close();
	emit shareListClosed();
}

void DlgShareList::cancel() {
	this->close();
	emit shareListClosed();
}
